/* Name of the package */
#undef PACKAGE

/* Version of package */
#undef VERSION

#undef JAVA2HTML_VERSION

#undef CPP2HTML_VERSION

#undef CHROOT_INPUT_DIR

@BOTTOM@

#include "cxxconfig.h"
